@@ -1,5 +1,7 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
+"""This module contains only filters, they are design to be apply to a row
+of a Vertical or Horizotal table."""
 
 
 # This file is part of Linshare cli.
@@ -25,93 +27,114 @@
 #
 
 
-from __future__ import unicode_literals
+
 import types
 import datetime
 import re
+import logging
+from linsharecli.common.cell import BaseCell
+
 
-# pylint: disable=R0921
-# pylint: disable=C0111
-# -----------------------------------------------------------------------------
 class Filter(object):
+    """TODO"""
+
     def __init__(self, prop, values=None):
         """ prop name and value(s)"""
         self.prop = prop
         self.values = values
+        classname = self.__class__.__name__.lower()
+        self.log = logging.getLogger("linsharecli.filters." + classname)
 
     def is_enable(self):
+        """Return true is the current filter is enabled and should be applied."""
         if self.values is None:
             return False
-        elif isinstance(self.values, list):
+        if isinstance(self.values, list):
+            # pylint: disable=len-as-condition
             if len(self.values) == 0:
                 return False
-            else:
-                for i in self.values:
-                    if i is not None:
-                        return True
-        else:
-            return True
+            for i in self.values:
+                if i is not None:
+                    return True
+            return False
+        return True
 
     def get_val(self, row):
+        """return values from the current row that need to be tested again the
+        current filter."""
         if isinstance(self.prop, list):
             vals = {}
             for prop in self.prop:
                 vals[prop] = self._get_val(row, prop)
             return vals
-        else:
-            return self._get_val(row, self.prop)
+        return self._get_val(row, self.prop)
 
     def _get_val(self, row, prop):
         val = row.get(prop)
         if val is None:
             raise ValueError("missing key : " + self.prop)
+        self.log.debug("value: '%s'", val)
+        self.log.debug("type: %s", type(val))
         return val
 
-# -----------------------------------------------------------------------------
+
 class PartialOr(Filter):
     """Get the current property into the current row, and match the result with
      a list of values"""
 
-    def __init__(self, prop, values, ignorecase=False):
+    def __init__(self, prop, values, ignorecase=False, match_raw=False):
         super(PartialOr, self).__init__(prop, values)
+        self.match_raw = match_raw
         if self.is_enable():
             if not isinstance(values, list):
                 raise ValueError("input values should be a list")
+            self.log.debug("values: %s", self.values)
             pattern = r"^.*(" + "|".join(self.values) + ").*$"
+            self.log.debug("raw pattern: %s", pattern)
             if ignorecase:
                 self.regex = re.compile(pattern, re.IGNORECASE)
             else:
                 self.regex = re.compile(pattern)
 
     def __call__(self, row):
+        # pylint: disable=too-many-return-statements
         if not self.is_enable():
             return True
         vals = self.get_val(row)
         if isinstance(vals, dict):
-            for val in vals.values():
-                if self.regex.match(val):
-                    return True
+            for val in list(vals.values()):
+                return self.__match(val)
         else:
-            if isinstance(vals, types.UnicodeType):
-                if self.regex.match(vals):
+            return self.__match(vals)
+
+    def __match(self, val):
+        if isinstance(val, str):
+            if self.regex.match(val):
+                return True
+        elif isinstance(val, BaseCell):
+            self.log.debug("cell type: %s", type(val))
+            if self.match_raw:
+                if self.regex.match(val.value):
                     return True
             else:
-                if self.regex.match(str(vals)):
+                if val.match(self.regex):
                     return True
+        else:
+            if self.regex.match(val):
+                return True
         return False
 
 
-# -----------------------------------------------------------------------------
 class PartialMultipleAnd(Filter):
     """Get the current property into the current row, and match the result with
      a list of values"""
 
     def __init__(self, propvalues, ignorecase=False):
-        super(PartialMultipleAnd, self).__init__(propvalues.keys(), propvalues.values())
+        super(PartialMultipleAnd, self).__init__(list(propvalues.keys()), list(propvalues.values()))
         self.regex = {}
         self.propvalues = propvalues
         if self.is_enable():
-            for key, value in propvalues.items():
+            for key, value in list(propvalues.items()):
                 self.regex[key] = None
                 if value is not None:
                     pattern = r"^.*" + value + ".*$"
@@ -124,14 +147,13 @@ class PartialMultipleAnd(Filter):
         if not self.is_enable():
             return True
         vals = self.get_val(row)
-        for key, val in vals.items():
+        for key, val in list(vals.items()):
             if self.regex[key]:
                 if not self.regex[key].match(val):
                     return False
         return True
 
 
-# -----------------------------------------------------------------------------
 class PartialDate(Filter):
     """Get the current property into the current row, and match the result with
      a list of values"""
@@ -139,7 +161,7 @@ class PartialDate(Filter):
     def __init__(self, prop, value):
         super(PartialDate, self).__init__(prop, value)
         if self.is_enable():
-            pattern = r"" + str(value)
+            pattern = r"^.*" + value + ".*$"
             self.regex = re.compile(pattern)
 
     def __call__(self, row):
@@ -147,26 +169,23 @@ class PartialDate(Filter):
             return True
         vals = self.get_val(row)
         if isinstance(vals, dict):
-            for val in vals.values():
+            for val in list(vals.values()):
                 if self.regex.match(val):
                     return True
         else:
             formatt = "{da:%Y-%m-%d %H:%M:%S}"
             vals = formatt.format(
                 da=datetime.datetime.fromtimestamp(vals / 1000))
+            self.log.debug("type of values: %s", vals)
             if self.regex.match(vals):
                 return True
         return False
 
 
-# -----------------------------------------------------------------------------
 class Equal(Filter):
     """Get the current property into the current row, and test equality.
     Only one value is possible"""
 
-    def __init__(self, prop, values=None):
-        super(Equal, self).__init__(prop, values)
-
     def __call__(self, row):
         if not self.is_enable():
             return True
@@ -176,14 +195,10 @@ class Equal(Filter):
         return False
 
 
-# -----------------------------------------------------------------------------
 class Equals(Filter):
     """Get the current property into the current row, and test equality.
     A list of values will be test"""
 
-    def __init__(self, prop, values=None):
-        super(Equals, self).__init__(prop, values)
-
     def __call__(self, row):
         if not self.is_enable():
             return True
